import './ValidationResultType.dart';

/// Result generated by schema validation

class ValidationResult {
  String _path;
  ValidationResultType _type;
  String _code;
  String _message;
  dynamic _expected;
  dynamic _actual;

  /// Creates a new instance of validation ressult and sets its values.
  ///
  /// - [path]      a dot notation path of the validated element.
  /// - [type]      a type of the validation result: Information, Warning, or Error.
  /// - [code]      an error code.
  /// - [message]   a human readable message.
  /// - [expected]  an value expected by schema validation.
  /// - [actual]    an actual value found by schema validation.
  ///
  /// See [ValidationResultType]

  ValidationResult(
      [String path = null,
      ValidationResultType type = null,
      String code = null,
      String message = null,
      dynamic expected = null,
      dynamic actual = null]) {
    this._path = path;
    this._type = type;
    this._code = code;
    this._message = message;
    this._expected = expected;
    this._actual = actual;
  }

  /// Gets dot notation path of the validated element.
  ///
  /// Returns the path of the validated element.

  String getPath() {
    return this._path;
  }

  /// Gets the type of the validation result: Information, Warning, or Error.
  ///
  /// Returns the type of the validation result.
  ///
  /// See [ValidationResultType]

  ValidationResultType getType() {
    return this._type;
  }

  /// Gets the error code.
  ///
  /// Returns the error code

  String getCode() {
    return this._code;
  }

  /// Gets the human readable message.
  ///
  /// Returns the result message.

  String getMessage() {
    return this._message;
  }

  /// Gets the value expected by schema validation.
  ///
  /// Returns the expected value.

  dynamic getExpected() {
    return this._expected;
  }

  /// Gets the actual value found by schema validation.
  ///
  /// Returns the actual value.

  dynamic getActual() {
    return this._actual;
  }
}
